@@ -8,16 +8,13 @@ import com.fasterxml.jackson.annotation.JsonProperty;
 import java.util.Map;
 import java.util.List;
 import java.util.Set;
-import lombok.AllArgsConstructor;
+import lombok.AllArgsConstructor;{{ '\nimport lombok.NoArgsConstructor;' if  no_args_constructor_required }}
 import lombok.Builder;
 import lombok.Data;
-import lombok.NoArgsConstructor;
-
 
 @Data
 @Builder
-@AllArgsConstructor
-@NoArgsConstructor
+@AllArgsConstructor{{ '\n@NoArgsConstructor' if no_args_constructor_required }}
 @JsonAutoDetect(fieldVisibility = Visibility.ANY, getterVisibility = Visibility.NONE, setterVisibility = Visibility.NONE)
 public class {{ model_name|uppercase_first_letter }} {
     {% for name, type in properties.items() %}
